==> apache-iotdb-1.3.4-1-source-release.zip: apache-iotdb-1.3.4-1/iotdb-client/service-rpc/src/main/java/org/apache/iotdb/rpc/subscription/payload/poll/ErrorPayload.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.rpc.subscription.payload.poll;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Objects;

public class ErrorPayload implements SubscriptionPollPayload {

  /** The error message describing the issue. */
  private transient String errorMessage;

  /** Indicates whether the error is critical. */
  private transient boolean critical;

  public String getErrorMessage() {
    return errorMessage;
  }

  public boolean isCritical() {
    return critical;
  }

  public ErrorPayload() {}

  public ErrorPayload(final String errorMessage, final boolean critical) {
    this.errorMessage = errorMessage;
    this.critical = critical;
  }

  @Override
  public void serialize(final DataOutputStream stream) throws IOException {
    ReadWriteIOUtils.write(errorMessage, stream);
    ReadWriteIOUtils.write(critical, stream);
  }

  @Override
  public SubscriptionPollPayload deserialize(final ByteBuffer buffer) {
    this.errorMessage = ReadWriteIOUtils.readString(buffer);
    this.critical = ReadWriteIOUtils.readBool(buffer);
    return this;
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }
    final ErrorPayload that = (ErrorPayload) obj;
    return Objects.equals(this.errorMessage, that.errorMessage)
        && Objects.equals(this.critical, that.critical);
  }

  @Override
  public int hashCode() {
    return Objects.hash(errorMessage, critical);
  }

  @Override
  public String toString() {
    return "ErrorPayload{errorMessage=" + errorMessage + ", critical=" + critical + "}";
  }
}

==> apache-iotdb-1.3.5-source-release.zip: apache-iotdb-1.3.5/iotdb-client/service-rpc/src/main/java/org/apache/iotdb/rpc/subscription/payload/poll/ErrorPayload.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.rpc.subscription.payload.poll;

import org.apache.tsfile.utils.ReadWriteIOUtils;

import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Objects;

public class ErrorPayload implements SubscriptionPollPayload {

  private static final String OUTDATED_ERROR_MSG = "outdated subscription event";
  public static final ErrorPayload OUTDATED_ERROR_PAYLOAD =
      new ErrorPayload(OUTDATED_ERROR_MSG, false);

  /** The error message describing the issue. */
  private transient String errorMessage;

  /** Indicates whether the error is critical. */
  private transient boolean critical;

  public String getErrorMessage() {
    return errorMessage;
  }

  public boolean isCritical() {
    return critical;
  }

  public ErrorPayload() {}

  public ErrorPayload(final String errorMessage, final boolean critical) {
    this.errorMessage = errorMessage;
    this.critical = critical;
  }

  @Override
  public void serialize(final DataOutputStream stream) throws IOException {
    ReadWriteIOUtils.write(errorMessage, stream);
    ReadWriteIOUtils.write(critical, stream);
  }

  @Override
  public SubscriptionPollPayload deserialize(final ByteBuffer buffer) {
    this.errorMessage = ReadWriteIOUtils.readString(buffer);
    this.critical = ReadWriteIOUtils.readBool(buffer);
    return this;
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }
    final ErrorPayload that = (ErrorPayload) obj;
    return Objects.equals(this.errorMessage, that.errorMessage)
        && Objects.equals(this.critical, that.critical);
  }

  @Override
  public int hashCode() {
    return Objects.hash(errorMessage, critical);
  }

  @Override
  public String toString() {
    return "ErrorPayload{errorMessage=" + errorMessage + ", critical=" + critical + "}";
  }
}
